
<!DOCTYPE html>
<html>
<head>
  <style type="text/css">
    body {
      text-align: center;
      background-size: 100%;
    }
    h1, h2 {
      color: black;
      font-family: "Courier New";
    }
  </style>


</head>

<body>
    <img src="static/images/logo.png", style="height:100px;width:100px">

    <h1>Type in a name please</h1>
    <form action="" method="post">
        <p>
            <input type=text name="username", placeholder="annotater name">        
        </p>
        
         <p>
            <input type=password name="password", placeholder="doesn't matter for now">        
        </p> 
        
        <p>
            <input type=submit name="Start">        
        </p>
    </form>
</body>